#include <stdio.h>
#include <math.h>
#include <stdlib.h>
//#include <stdint.h>

//using namespace std;

const double EPSILON = 10e-10;
const long MAX_POLY=500100;
const long X=0;
const long Y=1;
typedef int point[2];
point first_point;

//#define inline static

typedef long long int int64_t;

typedef struct
{
  long n;
  point p[MAX_POLY];
} poly;

point in[MAX_POLY];

inline int64_t dist64 (point a, point b)
{
  int64_t d=0;
  for (long i = 0;i<2;i++)
    d+=(a[i]-b[i])*(a[i]-b[i]);
  return d;
}

int64_t solve_maxdist(poly P)
{
  int i1, i2=1;
  int64_t bestbest_dist=0;
  for (i1=0; i1<P.n; i1++) {
    fprintf(stderr, "B=%lld\n", bestbest_dist);
    int64_t best_dist=0, new_dist=0;
    best_dist=0;
    int i2_cand=i2;
    while (1) {
      new_dist=dist64(P.p[i1], P.p[i2_cand]);
      if (new_dist>best_dist) {
        best_dist=new_dist;
        i2_cand++;
      } else break;
    }
    i2=i2_cand-1;
    if (best_dist>bestbest_dist) bestbest_dist=best_dist;
  }
  return bestbest_dist;
}

inline void copy_point (point a, point b)
{
  for (long i = 0; i < 2; i++)
    b[i]=a[i];
}

inline double sta(point a, point b, point c)
{
  return ((a[X]*b[Y]-a[Y]*b[X]+a[Y]*c[X]-a[X]*c[Y]+b[X]*c[Y]-c[X]*b[Y])/2.0);
}

inline bool ccw(point a, point b, point c)
{
  return (sta(a,b,c)>EPSILON);
}

inline int leftlower(point *p1, point *p2)
{
  if (fabs((*p1)[X]-(*p2[X])) > EPSILON)
  {
    if ((*p1)[X]>(*p2)[X])
      return 1;
    if ((*p1)[X]<(*p2)[X])
      return (-1);
  }
  if (fabs ((*p1)[Y]-(*p2)[Y]) > EPSILON)
  {
    if ((*p1)[Y]>(*p2)[Y])
      return 1;
    if ((*p1)[Y]<(*p2)[Y])
      return (-1);
  }
  return 0;
}

void sort_and_remove_duplicates(point in[], long *n)
{
  long i;
  long oldn;
  long hole;
  
  qsort (in, *n, sizeof (point), (int(*)(const void *, const void *)) leftlower);
  oldn=*n;
  hole=1;
  for (i = 1; i < oldn - 1; i++)
  {
    if ((in[hole-1][X]==in[i][X]) && (in[hole-1][Y]==in[i][Y]))
      (*n)--;
    else
    {
      copy_point (in[i],in[hole]);
      hole++;
    }
  }
  copy_point(in[oldn-1],in[hole]);
}

inline bool collinear (point a, point b, point c)
{
  return (fabs(sta(a,b,c))<=EPSILON);
}

inline double distance (point a, point b)
{
  double d=0.0;
  for (long i = 0;i<2;i++)
    d+=(a[i]-b[i])*(a[i]-b[i]);
  return (d);
}

inline int smaller_angle (point *p1, point *p2)
{
  if (collinear (first_point, *p1, *p2))
  {
    if (distance(first_point, *p1) <= distance (first_point,*p2))
      return -1;
    else 
      return 1;
  }
  if (ccw(first_point, *p1, *p2))
    return -1;
  else
    return 1;
}

void convex_hull (point in[], long n, poly *hull)
{
  long i;
  long top;

  if (n<=3)
  {
    for (i=0;i<n;i++)
      copy_point(in[i], hull->p[i]);
    hull->n=n;
    return;
  }
  sort_and_remove_duplicates (in, &n);
  copy_point (in[0], first_point);
  qsort (&(in[1]), n-1, sizeof (point), (int(*)(const void *, const void *))smaller_angle);
  if (collinear (in[0], in[1], in[2])==true)
  {
    copy_point(in[0],hull->p[0]);
    copy_point(in[n-1],hull->p[1]);
    hull->n=2;
    return;
  }
  copy_point(first_point, hull->p[0]);
  copy_point(in[1], hull->p[1]);
  copy_point(first_point, in[n]);
  top=1;
  i=2;
  while(i<=n)
  {
    if (!ccw(hull->p[top-1],hull->p[top],in[i]))
      top--;
    else
    {
      top++;
      copy_point(in[i],hull->p[top]);
      i++;
    }
    hull->n=top;
  }
}

void print_poly(poly *p)
{
  for (long i = 0; i < p->n; i++)
  {
    if (fabs (p->p[i][X]) <= EPSILON)
      p->p[i][X]=0;
    if (fabs (p->p[i][Y]) <= EPSILON)
      p->p[i][Y]=0;
    fprintf (stderr, "%d,%d\n",p->p[i][X],p->p[i][Y]);
  }
}

int main()
{
  poly hull;
  long n;
  long i;
  long ntc; // number of test cases
 
  scanf ("%ld", &ntc);
  for (long cntc=1;cntc<=ntc;cntc++)
  {
    scanf ("%ld", &n);
    fprintf(stderr, "n = %d\n", n);
    for (i=0;i<n;i++)
      scanf("%d %d", &(in[i][X]), &(in[i][Y]));
    convex_hull(in, n, &hull);
    print_poly(&hull);
    printf("%lld\n", solve_maxdist(hull));
  }
  return 0;
}
